@@ -86,7 +86,7 @@ static void nautilus_hardware_view_drag_data_received (GtkWidget
                                                        guint                      time);
 static void nautilus_hardware_view_class_init   (NautilusHardwareViewClass *klass);
 static void nautilus_hardware_view_init         (NautilusHardwareView      *view);
-static void nautilus_hardware_view_destroy            (GtkObject                 *object);
+static void nautilus_hardware_view_finalize            (GObject                 *object);
 static void hardware_view_load_location_callback      (NautilusView              *view,
                                                        const char                *location,
                                                        NautilusHardwareView      *hardware_view);
@@ -100,13 +100,13 @@ EEL_CLASS_BOILERPLATE (NautilusHardwareView, nautilus_hardware_view, GTK_TYPE_EV
 static void
 nautilus_hardware_view_class_init (NautilusHardwareViewClass *klass)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	
-	object_class = GTK_OBJECT_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
 	widget_class = GTK_WIDGET_CLASS (klass);
 
-	object_class->destroy = nautilus_hardware_view_destroy;
+	object_class->finalize = nautilus_hardware_view_finalize;
 	widget_class->drag_data_received  = nautilus_hardware_view_drag_data_received;
 }
 
@@ -185,7 +185,7 @@ nautilus_hardware_view_init (NautilusHardwareView *hardware_view)
 }
 
 static void
-nautilus_hardware_view_destroy (GtkObject *object)
+nautilus_hardware_view_finalize (GObject *object)
 {
 	NautilusHardwareView *hardware_view;
 
@@ -199,7 +199,7 @@ nautilus_hardware_view_destroy (GtkObject *object)
 
 	g_free (hardware_view->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /* Component embedding support */
@@ -438,7 +438,7 @@ setup_form_title (NautilusHardwareView *view,
 	if (image_name != NULL) {
  		file_name = gnome_program_locate_file (
                         NULL, GNOME_FILE_DOMAIN_PIXMAP, image_name, TRUE, NULL);
-
+		
 		if (file_name != NULL) {
 			temp_widget = gtk_image_new_from_file (file_name);
 			gtk_box_pack_start (GTK_BOX(temp_container), temp_widget, 0, 0, 8);		
@@ -448,7 +448,7 @@ setup_form_title (NautilusHardwareView *view,
 	}
 	
  	temp_widget = gtk_label_new (title_text);
-	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_X_LARGE);
+	eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_XX_LARGE);
 
 	gtk_box_pack_start (GTK_BOX (temp_container), temp_widget, 0, 0, 8);			 	
 	gtk_widget_show (temp_widget);
@@ -531,6 +531,7 @@ setup_overview_form (NautilusHardwareView *view)
 		
 		temp_widget = gtk_label_new (temp_text);
 		eel_gtk_label_set_scale (GTK_LABEL (temp_widget), PANGO_SCALE_LARGE);
+		gtk_label_set_justify (GTK_LABEL (temp_widget), GTK_JUSTIFY_CENTER);
 		g_free(temp_text);
 		gtk_box_pack_start(GTK_BOX(temp_box), temp_widget, 0, 0, 0 );			
 		gtk_widget_show (temp_widget);
@@ -574,15 +575,12 @@ setup_overview_form (NautilusHardwareView *view)
                                 
                                 /* Set the icon depending on the type of device */
                                 if (strcmp (ide_media, "disk\n") == 0) {
-                                        file_name = gnome_program_locate_file (NULL,
-						GNOME_FILE_DOMAIN_PIXMAP,
-						"document-icons/i-harddisk.png",
-						TRUE, NULL);
+                                        file_name = nautilus_pixmap_file ("HD_drive.png");
                                 } else if (strcmp (ide_media, "cdrom\n") == 0) {
                                         file_name = nautilus_pixmap_file ("CD_drive.png");
                                 } else {
                                         /* some other device ... still set an icon */
-                                        file_name = nautilus_pixmap_file ("i-harddisk.png");
+                                        file_name = nautilus_pixmap_file ("HD_drive.png");
                                 }
                                 
 				pixmap_widget = gtk_image_new_from_file (file_name);
