@@ -283,6 +283,8 @@ async_data_preference_changed_callback (gpointer callback_data)
 static void
 add_preferences_callbacks (void)
 {
+	nautilus_global_preferences_init ();
+
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
 				      filtering_changed_callback,
 				      NULL);
@@ -819,26 +821,35 @@ call_files_added_free_list (gpointer key, gpointer value, gpointer user_data)
 	g_list_free (value);
 }
 
+static void
+call_files_changed_common (NautilusDirectory *directory, GList *file_list)
+{
+	GList *node;
+
+	for (node = file_list; node != NULL; node = node->next) {
+		nautilus_directory_add_file_to_work_queue (directory, node->data);
+	}
+	nautilus_directory_async_state_changed (directory);
+	nautilus_directory_emit_change_signals (directory, file_list);
+}
+
 static void
 call_files_changed_free_list (gpointer key, gpointer value, gpointer user_data)
 {
-	g_assert (NAUTILUS_IS_DIRECTORY (key));
 	g_assert (value != NULL);
 	g_assert (user_data == NULL);
 
-	nautilus_directory_emit_change_signals (key, value);
+	call_files_changed_common (NAUTILUS_DIRECTORY (key), value);
 	g_list_free (value);
 }
 
 static void
 call_files_changed_unref_free_list (gpointer key, gpointer value, gpointer user_data)
 {
-	g_assert (NAUTILUS_IS_DIRECTORY (key));
 	g_assert (value != NULL);
 	g_assert (user_data == NULL);
 
-	nautilus_directory_async_state_changed (key);
-	nautilus_directory_emit_change_signals (key, value);
+	call_files_changed_common (NAUTILUS_DIRECTORY (key), value);
 	nautilus_file_list_free (value);
 }
 
@@ -965,10 +976,13 @@ nautilus_directory_notify_files_changed (GList *uris)
 		/* Find the file. */
 		file = nautilus_file_get_existing (uri);
 		if (file != NULL) {
-			/* Tell it to re-get info and emit a changed
-			 * signal.
+			/* Tell it to re-get info now, and later emit
+			 * a changed signal.
 			 */
 			file->details->file_info_is_up_to_date = FALSE;
+			file->details->top_left_text_is_up_to_date = FALSE;
+			file->details->link_info_is_up_to_date = FALSE;
+
 			hash_table_list_prepend (changed_lists,
 						 file->details->directory,
 						 file);
@@ -1009,7 +1023,7 @@ nautilus_directory_notify_files_removed (GList *uris)
 
 		/* Find the file. */
 		file = nautilus_file_get_existing (uri);
-		if (file != NULL) {
+		if (file != NULL && !nautilus_file_rename_in_progress (file)) {
 			/* Mark it gone and prepare to send the changed signal. */
 			nautilus_file_mark_gone (file);
 			hash_table_list_prepend (changed_lists,
