@@ -195,7 +195,7 @@ static guint signals[LAST_SIGNAL];
 
 static void            nautilus_volume_monitor_init       (NautilusVolumeMonitor      *desktop_mounter);
 static void            nautilus_volume_monitor_class_init (NautilusVolumeMonitorClass *klass);
-static void            nautilus_volume_monitor_destroy          (GtkObject                  *object);
+static void            nautilus_volume_monitor_finalize         (GObject                    *object);
 static char *          get_iso9660_volume_name                  (NautilusVolume             *volume,
 								 int                         volume_fd);
 static GHashTable *    load_file_system_table                   (void);
@@ -219,6 +219,7 @@ static GHashTable *    create_readable_mount_point_name_table   (void);
 static int             get_cdrom_type                           (const char                 *vol_dev_path,
 								 int                        *fd);
 static void            nautilus_volume_free                     (NautilusVolume             *volume);
+static void            nautilus_file_system_type_free           (NautilusFileSystemType     *type);
 
 #ifdef HAVE_CDDA
 static gboolean        locate_audio_cd                          (void);
@@ -238,7 +239,9 @@ load_file_system_table (void)
 	xmlChar *name, *default_volume_name, *trash;
 	NautilusFileSystemType *type;
 
-	table = g_hash_table_new (g_str_hash, g_str_equal);
+	/* We don't provide a free_key func since the key is freed by the value_free func */
+	table = g_hash_table_new_full (g_str_hash, g_str_equal,
+				       NULL, (GDestroyNotify) nautilus_file_system_type_free);
 	
 	file_system_attributes_file = nautilus_get_data_file_path ("filesystem-attributes.xml");
 	if (file_system_attributes_file == NULL) {
@@ -292,11 +295,11 @@ nautilus_volume_monitor_init (NautilusVolumeMonitor *monitor)
 static void
 nautilus_volume_monitor_class_init (NautilusVolumeMonitorClass *klass)
 {
-	GtkObjectClass		*object_class;
+	GObjectClass		*object_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
+	object_class = G_OBJECT_CLASS (klass);
 
-	object_class->destroy = nautilus_volume_monitor_destroy;
+	object_class->finalize = nautilus_volume_monitor_finalize;
 
 	signals[VOLUME_MOUNTED] 
 		= g_signal_new ("volume_mounted",
@@ -354,7 +357,7 @@ nautilus_volume_monitor_class_init (NautilusVolumeMonitorClass *klass)
 }
 
 static void
-nautilus_volume_monitor_destroy (GtkObject *object)
+nautilus_volume_monitor_finalize (GObject *object)
 {
 	NautilusVolumeMonitor *monitor;
 	
@@ -370,12 +373,15 @@ nautilus_volume_monitor_destroy (GtkObject *object)
 	/* Clean up readable names table */	
 	g_hash_table_destroy (monitor->details->readable_mount_point_names);
 
+	/* Clean up file system table */
+	g_hash_table_destroy (monitor->details->file_system_table);
+	
 	/* Clean up details */	 
 	g_free (monitor->details);
 
 	global_volume_monitor = NULL;
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void
@@ -758,6 +764,14 @@ nautilus_volume_get_mount_path (const NautilusVolume *volume)
 	return volume->mount_path;
 }
 
+const char *
+nautilus_volume_get_device_path (NautilusVolume *volume)
+{
+	g_return_val_if_fail (volume != NULL, NULL);
+	return volume->device_path;
+}
+
+
 NautilusDeviceType
 nautilus_volume_get_device_type (const NautilusVolume *volume)
 {
@@ -1088,7 +1102,7 @@ get_mount_list (NautilusVolumeMonitor *monitor)
                         file_system_type_name = eel_string_list_nth (list, 2);
                         volume = create_volume (device_path, mount_path);
 			if (eel_string_list_get_length (list) >= 4 &&
-			    option_list_has_option (eel_string_list_nth (list, 3), MNTOPT_RO))
+			    option_list_has_option (eel_string_list_peek_nth (list, 3), MNTOPT_RO))
 				volume->is_read_only = TRUE;
                         volumes = finish_creating_volume_and_prepend
 				(monitor, volume, file_system_type_name, volumes);
@@ -1553,7 +1567,7 @@ mount_unmount_callback (void *arg)
 	const char *old_locale;
 
 	info = arg;
-	
+
 	if (info != NULL) {	
 		old_locale = g_getenv ("LC_ALL");
 		eel_setenv ("LC_ALL", "C", TRUE);
@@ -1594,7 +1608,7 @@ nautilus_volume_monitor_mount_unmount_removable (NautilusVolumeMonitor *monitor,
 	const char *name;
 
 	volume = NULL;
-	
+
 	/* Check and see if volume exists in mounts already */
 	for (p = monitor->details->mounts; p != NULL; p = p->next) {
 		volume = (NautilusVolume *)p->data;
@@ -1703,6 +1717,14 @@ nautilus_volume_free (NautilusVolume *volume)
 	g_free (volume);
 }
 
+static void
+nautilus_file_system_type_free (NautilusFileSystemType *type)
+{
+	g_free (type->name);
+	g_free (type->default_volume_name);
+	g_free (type);
+}
+
 static char *
 get_iso9660_volume_name (NautilusVolume *volume, int fd)
 {
@@ -1731,8 +1753,9 @@ load_additional_mount_list_info (GList *volume_list)
 		/* These are set up by get_current_mount_list for Solaris. */
 		volume->is_removable = volume_is_removable (volume);
 #endif
-
-		volume->volume_name = mount_volume_make_name (volume);
+		if (volume->volume_name == NULL) {
+			volume->volume_name = mount_volume_make_name (volume);
+		}
 	}
 }
 
@@ -1747,18 +1770,34 @@ finish_creating_volume (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 	volume->file_system_type = g_hash_table_lookup
 		(monitor->details->file_system_table, file_system_type_name);
 
-	if (strcmp (file_system_type_name, "auto") == 0) {		
+	if (strcmp (file_system_type_name, "auto") == 0) {
 		ok = mount_volume_auto_add (volume);
-	} else if (strcmp (file_system_type_name, "cdda") == 0) {		
+	} else if (strcmp (file_system_type_name, "cdda") == 0) {
 		ok = mount_volume_cdda_add (volume);
-	} else if (strcmp (file_system_type_name, "iso9660") == 0) {		    		
+	} else if (strcmp (file_system_type_name, "iso9660") == 0) {
 		ok = mount_volume_iso9660_add (volume);
-	} else if (strcmp (file_system_type_name, "nfs") == 0) {		
+	} else if (strcmp (file_system_type_name, "nfs") == 0) {
 		ok = mount_volume_nfs_add (volume);
+		volume->is_removable = FALSE;
+		return ok;
+	} else if (strcmp (file_system_type_name, "smbfs") == 0) {
+		volume->device_type = NAUTILUS_DEVICE_SMB;
+		volume->is_removable = TRUE;
+		return TRUE;
+	} else if ((strcmp (file_system_type_name, "hfs") == 0)
+			|| (strcmp (file_system_type_name, "hfsplus") == 0)) {
+		volume->device_type = NAUTILUS_DEVICE_APPLE;
+		ok = TRUE;
+	} else if ((strcmp (file_system_type_name, "vfat") == 0)
+			|| (strcmp (file_system_type_name, "fat") == 0)
+			|| (strcmp (file_system_type_name, "ntfs") == 0)
+			|| (strcmp (file_system_type_name, "msdos") == 0)) {
+		volume->device_type = NAUTILUS_DEVICE_WINDOWS;
+		ok = TRUE;
 	} else {
 		ok = TRUE;
 	}
-	
+
 	if (!ok) {
 		return FALSE;
 	}
@@ -1771,7 +1810,8 @@ finish_creating_volume (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 	if (eel_str_has_prefix (volume->mount_path, "/mnt/")) {		
 		name = volume->mount_path + strlen ("/mnt/");
 		
-		if (eel_str_has_prefix (name, "cdrom")) {
+		if (eel_str_has_prefix (name, "cdrom")
+				|| eel_str_has_prefix (name, "burn")) {
 			volume->device_type = NAUTILUS_DEVICE_CDROM_DRIVE;
 			volume->is_removable = TRUE;
 		} else if (eel_str_has_prefix (name, "floppy")) {
@@ -1788,15 +1828,46 @@ finish_creating_volume (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 			volume->is_removable = TRUE;
 		} else if (eel_str_has_prefix (name, "camera")) {
 			volume->device_type = NAUTILUS_DEVICE_CAMERA;
-			volume->is_removable = TRUE;					
-		} else if (eel_str_has_prefix (name, "memstick")) {
+			volume->is_removable = TRUE;
+		} else if (eel_str_has_prefix (name, "memstick")
+				|| eel_str_has_prefix (name, "ram")) {
 			volume->device_type = NAUTILUS_DEVICE_MEMORY_STICK;
 			volume->is_removable = TRUE;
+		} else if (eel_str_has_prefix (name, "ipod")) {
+			volume->device_type = NAUTILUS_DEVICE_APPLE;
+			volume->is_removable = TRUE;
 		} else {
 			volume->is_removable = FALSE;
 		}
-	}
-	
+	} else if (eel_str_has_prefix (volume->device_path, "/vol/")) {
+			name = volume->mount_path + strlen ("/");
+		
+			if (eel_str_has_prefix (name, "cdrom")) {
+				volume->device_type = NAUTILUS_DEVICE_CDROM_DRIVE;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (name, "floppy")) {
+				volume->device_type = NAUTILUS_DEVICE_FLOPPY_DRIVE;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (volume->device_path, floppy_device_path_prefix)) {
+				volume->device_type = NAUTILUS_DEVICE_FLOPPY_DRIVE;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (name, "zip")) {
+				volume->device_type = NAUTILUS_DEVICE_ZIP_DRIVE;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (name, "jaz")) {
+				volume->device_type = NAUTILUS_DEVICE_JAZ_DRIVE;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (name, "camera")) {
+				volume->device_type = NAUTILUS_DEVICE_CAMERA;
+				volume->is_removable = TRUE;
+			} else if (eel_str_has_prefix (name, "memstick")) {
+				volume->device_type = NAUTILUS_DEVICE_MEMORY_STICK;
+				volume->is_removable = TRUE;
+			} else {
+				volume->is_removable = FALSE;
+			}
+		}
+
 	return TRUE;
 }
 
@@ -1818,24 +1889,21 @@ char *
 nautilus_volume_monitor_get_mount_name_for_display (NautilusVolumeMonitor *monitor,
 						    const NautilusVolume *volume)
 {
-	const char *name, *found_name;
+	const char *found_name;
+	char *name;
 
 	g_return_val_if_fail (monitor != NULL, NULL);
 	g_return_val_if_fail (volume != NULL, NULL);
-	
-	name = strrchr (volume->mount_path, '/');
-	if (name != NULL) {
-		name = name + 1;
-	} else {
-		name = volume->mount_path;
-	}
-	
+
+	name = g_path_get_basename (volume->mount_path);
+
 	/* Look for a match in our localized mount name list */
 	found_name = g_hash_table_lookup (monitor->details->readable_mount_point_names, name);
 	if (found_name != NULL) {
+		g_free (name);
 		return g_strdup (found_name);
 	} else {
-		return g_strdup (name);
+		return name;
 	}
 }
 
