@@ -429,11 +429,17 @@ create_mount_link (FMDesktopIconView *icon_view,
 	case NAUTILUS_DEVICE_NFS:
 		icon_name = "i-nfs";
 		break;
+
+	case NAUTILUS_DEVICE_SMB:
+		icon_name = "i-smb";
+		break;
 	
 	case NAUTILUS_DEVICE_ZIP_DRIVE:
 		icon_name = "i-zipdisk";
 		break;
 
+	case NAUTILUS_DEVICE_APPLE:
+	case NAUTILUS_DEVICE_WINDOWS:
 	case NAUTILUS_DEVICE_CAMERA:
 	case NAUTILUS_DEVICE_UNKNOWN:
 		break;
@@ -798,7 +804,7 @@ volume_ops_callback (BonoboUIComponent *component, gpointer data, const char *ve
 	GError *error;
 	GtkWidget *dialog;
 
-			    
+
         g_assert (FM_IS_DIRECTORY_VIEW (data));
         
         view = FM_DIRECTORY_VIEW (data);
@@ -810,7 +816,8 @@ volume_ops_callback (BonoboUIComponent *component, gpointer data, const char *ve
 	selection = fm_directory_view_get_selection (view);
 	
 	file = NAUTILUS_FILE (selection->data);
-	if (nautilus_file_is_local (file)) {
+	
+	if (!nautilus_file_is_local (file)) {
 		nautilus_file_list_free (selection);
 		return;
 	}
